@@ -1,4 +1,5 @@
 # Copyright (c) 2014-2018 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2019 Jordi Romera <jordiromera@users.sourceforge.net>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -12,6 +13,12 @@
 
 from gi.repository import GLib, GObject, Gio
 
+from gi.repository.Gio import FILE_ATTRIBUTE_STANDARD_NAME, \
+                              FILE_ATTRIBUTE_STANDARD_TYPE, \
+                              FILE_ATTRIBUTE_STANDARD_IS_HIDDEN,\
+                              FILE_ATTRIBUTE_TIME_CHANGED,\
+                              FILE_ATTRIBUTE_TIME_MODIFIED
+
 from gettext import gettext as _
 from threading import Thread
 from time import time
@@ -23,7 +30,14 @@ from lollypop.sqlcursor import SqlCursor
 from lollypop.tagreader import TagReader
 from lollypop.logger import Logger
 from lollypop.database_history import History
-from lollypop.utils import is_audio, is_pls
+from lollypop.utils import is_audio, is_pls, get_mtime, profile
+
+
+SCAN_QUERY_INFO = "{},{},{},{},{}".format(FILE_ATTRIBUTE_STANDARD_NAME,
+                                          FILE_ATTRIBUTE_STANDARD_TYPE,
+                                          FILE_ATTRIBUTE_STANDARD_IS_HIDDEN,
+                                          FILE_ATTRIBUTE_TIME_CHANGED,
+                                          FILE_ATTRIBUTE_TIME_MODIFIED)
 
 
 class CollectionScanner(GObject.GObject, TagReader):
@@ -72,9 +86,10 @@ class CollectionScanner(GObject.GObject, TagReader):
                 if not uris:
                     return
 
+            # Register to progressbar
             App().window.container.progress.add(self)
-            App().window.container.progress.set_fraction(0.0, self)
-
+            App().window.container.progress.set_fraction(0, self)
+            # Launch scan in a separate thread
             self.__thread = Thread(target=self.__scan, args=(uris, saved))
             self.__thread.daemon = True
             self.__thread.start()
@@ -94,60 +109,6 @@ class CollectionScanner(GObject.GObject, TagReader):
 #######################
 # PRIVATE             #
 #######################
-    def __get_objects_for_uris(self, uris):
-        """
-            Return all tracks/dirs for uris
-            @param uris as string
-            @return (track uri as [str], track dirs as [str])
-        """
-        tracks = []
-        files = []
-        track_dirs = []
-        walk_uris = list(uris)
-        while walk_uris:
-            uri = walk_uris.pop(0)
-            try:
-                # Directly add files, walk through directories
-                f = Gio.File.new_for_uri(uri)
-                info = f.query_info(
-                    "standard::name,standard::type,standard::is-hidden",
-                    Gio.FileQueryInfoFlags.NONE,
-                    None)
-                if info.get_file_type() == Gio.FileType.DIRECTORY:
-                    track_dirs.append(uri)
-                    infos = f.enumerate_children(
-                        "standard::name,standard::type,standard::is-hidden",
-                        Gio.FileQueryInfoFlags.NONE,
-                        None)
-                    for info in infos:
-                        f = infos.get_child(info)
-                        child_uri = f.get_uri()
-                        if info.get_is_hidden():
-                            continue
-                        elif info.get_file_type() == Gio.FileType.DIRECTORY:
-                            track_dirs.append(child_uri)
-                            walk_uris.append(child_uri)
-                        else:
-                            files.append(f)
-                else:
-                    files.append(f)
-            except Exception as e:
-                Logger.error("CollectionScanner::__get_objects_for_uris(): %s"
-                             % e)
-        for f in files:
-            try:
-                if is_pls(f):
-                    App().playlists.import_tracks(f)
-                elif is_audio(f):
-                    tracks.append(f.get_uri())
-                else:
-                    Logger.debug("%s not detected as a music file" %
-                                 f.get_uri())
-            except Exception as e:
-                Logger.error("CollectionScanner::__get_objects_for_uris(): %s"
-                             % e)
-        return (tracks, track_dirs)
-
     def __update_progress(self, current, total):
         """
             Update progress bar status
@@ -168,6 +129,65 @@ class CollectionScanner(GObject.GObject, TagReader):
         if App().settings.get_value("artist-artwork"):
             App().art.cache_artists_info()
 
+    def __add_monitor(self, dirs):
+        """
+            Monitor any change in a list of directory
+            @param dirs as str or list of directory to be monitored
+        """
+        if self.__inotify is None:
+            return
+        # Add monitors on dirs
+        for d in dirs:
+            # Handle a stop request
+            if self.__thread is None:
+                break
+            if d.startswith("file://"):
+                self.__inotify.add_monitor(d)
+
+    @profile
+    def __get_objects_for_uris(self, uris):
+        """
+            Get all tracks and dirs in uris
+            @param uris as string
+            @return (tracks as [mtime: int, uri: str], dirs as [uri: str])
+        """
+        files = []
+        dirs = []
+        walk_uris = list(uris)
+        while walk_uris:
+            uri = walk_uris.pop(0)
+            try:
+                # Directly add files, walk through directories
+                f = Gio.File.new_for_uri(uri)
+                info = f.query_info(SCAN_QUERY_INFO,
+                                    Gio.FileQueryInfoFlags.NONE,
+                                    None)
+                if info.get_file_type() == Gio.FileType.DIRECTORY:
+                    dirs.append(uri)
+                    infos = f.enumerate_children(SCAN_QUERY_INFO,
+                                                 Gio.FileQueryInfoFlags.NONE,
+                                                 None)
+                    for info in infos:
+                        f = infos.get_child(info)
+                        child_uri = f.get_uri()
+                        if info.get_is_hidden():
+                            continue
+                        elif info.get_file_type() == Gio.FileType.DIRECTORY:
+                            dirs.append(child_uri)
+                            walk_uris.append(child_uri)
+                        else:
+                            mtime = get_mtime(info)
+                            files.append((mtime, child_uri))
+                else:
+                    mtime = get_mtime(info)
+                    files.append((mtime, uri))
+            except Exception as e:
+                Logger.error("CollectionScanner::__get_objects_for_uris(): %s"
+                             % e)
+        files.sort(reverse=True)
+        return (files, dirs)
+
+    @profile
     def __scan(self, uris, saved):
         """
             Scan music collection for music files
@@ -175,103 +195,120 @@ class CollectionScanner(GObject.GObject, TagReader):
             @param saved as bool
             @thread safe
         """
-        modifications = False
         if self.__history is None:
             self.__history = History()
-        mtimes = App().tracks.get_mtimes()
-        (new_tracks, new_dirs) = self.__get_objects_for_uris(uris)
-        orig_tracks = App().tracks.get_uris()
-        was_empty = len(orig_tracks) == 0
 
-        count = len(new_tracks) + len(orig_tracks)
-        # Add monitors on dirs
-        if self.__inotify is not None:
-            for d in new_dirs:
-                if d.startswith("file://"):
-                    self.__inotify.add_monitor(d)
+        (files, dirs) = self.__get_objects_for_uris(uris)
+
+        new_tracks = self.__scan_files(files, saved)
+        self.__add_monitor(dirs)
+
+        GLib.idle_add(self.__finish, new_tracks and saved)
 
-        i = 0
-        # Look for new files/modified file
-        SqlCursor.add(App().db)
-        try:
-            to_add = []
-            for uri in new_tracks:
-                if self.__thread is None:
-                    SqlCursor.remove(App().db)
-                    return
-                try:
-                    GLib.idle_add(self.__update_progress, i, count)
-                    f = Gio.File.new_for_uri(uri)
-                    # We do not use time::modified because many tag editors
-                    # just preserve this setting
-                    try:
-                        info = f.query_info("time::changed",
-                                            Gio.FileQueryInfoFlags.NONE,
-                                            None)
-                        mtime = int(info.get_attribute_as_string(
-                            "time::changed"))
-                    except:  # Fallback for remote fs
-                        info = f.query_info("time::modified",
-                                            Gio.FileQueryInfoFlags.NONE,
-                                            None)
-                        mtime = int(info.get_attribute_as_string(
-                            "time::modified"))
-                    # If songs exists and mtime unchanged, continue,
-                    # else rescan
-                    if uri in orig_tracks:
-                        orig_tracks.remove(uri)
-                        i += 1
-                        if not saved or mtime <= mtimes.get(uri, mtime + 1):
-                            i += 1
-                            continue
-                        else:
-                            SqlCursor.allow_thread_execution(App().db)
-                            self.__del_from_db(uri)
-                    # If not saved, use 0 as mtime, easy delete on quit
-                    if not saved:
-                        mtime = 0
-                    # On first scan, use modification time
-                    # Else, use current time
-                    elif not was_empty:
-                        mtime = int(time())
-                    to_add.append((uri, mtime))
-                except Exception as e:
-                    Logger.error("CollectionScanner::__scan(mtime): %s" % e)
-            if to_add or orig_tracks:
-                modifications = True
-            # Clean deleted files
-            # Now because we need to populate history
-            # Only if we are saving
-            if saved:
-                for uri in orig_tracks:
-                    i += 1
-                    GLib.idle_add(self.__update_progress, i, count)
-                    self.__del_from_db(uri)
-                    SqlCursor.allow_thread_execution(App().db)
-            # Add files to db
-            for (uri, mtime) in to_add:
-                try:
-                    Logger.debug("Adding file: %s" % uri)
-                    i += 1
-                    GLib.idle_add(self.__update_progress, i, count)
-                    self.__add2db(uri, mtime)
-                    SqlCursor.allow_thread_execution(App().db)
-                except Exception as e:
-                    Logger.error("CollectionScanner::__scan(add): %s, %s" %
-                                 (e, uri))
-        except Exception as e:
-            Logger.error("CollectionScanner::__scan(): %s" % e)
-        SqlCursor.commit(App().db)
-        SqlCursor.remove(App().db)
-        GLib.idle_add(self.__finish, modifications and saved)
         if not saved:
             self.__play_new_tracks(new_tracks)
+
         del self.__history
         self.__history = None
 
+    def __scan_to_handle(self, f):
+        """
+            Check if file has to be handle by scanner
+            @param f as Gio.File
+            @return bool
+        """
+        try:
+            # Scan file
+            if is_pls(f):
+                # Handle playlist
+                App().playlists.import_tracks(f)
+            elif is_audio(f):
+                return True
+            else:
+                Logger.debug("Not detected as a music file: %s" % f.get_uri())
+        except Exception as e:
+            Logger.error("CollectionScanner::__scan_to_handle(): %s" % e)
+        return False
+
+    def __scan_add(self, uri, mtime):
+        """
+            Add audio file to database
+            @param uri as str
+            @param mtime as float
+        """
+        try:
+            Logger.debug("Adding file: %s" % uri)
+            self.__add2db(uri, mtime)
+            SqlCursor.allow_thread_execution(App().db)
+        except Exception as e:
+            Logger.error("CollectionScanner::__scan_add(add): "
+                         "%s, %s" % (e, uri))
+
+    def __scan_del(self, uri):
+        """
+            Delete file from DB
+            @param uri as str
+        """
+        try:
+            self.__del_from_db(uri)
+            SqlCursor.allow_thread_execution(App().db)
+        except Exception as e:
+            Logger.error("CollectionScanner::__scan_del: %s" % e)
+
+    @profile
+    def __scan_files(self, files, saved):
+        """
+            Scan music collection for new audio files
+            @param files as [(int, str)]
+            @return new track uris as [str]
+            @thread safe
+        """
+        new_tracks = []
+        # Get mtime of all tracks to detect which has to be updated
+        mtimes = App().tracks.get_mtimes()
+        # Get uris of all tracks to detect which has to be deleted
+        to_delete = App().tracks.get_uris()
+        SqlCursor.add(App().db)
+        try:
+            count = len(files)
+            i = 0
+            while files:
+                # Handle a stop request
+                if self.__thread is None:
+                    return new_tracks
+                try:
+                    (mtime, uri) = files.pop(0)
+                    f = Gio.File.new_for_uri(uri)
+                    already_in_db = uri in to_delete
+                    if already_in_db:
+                        to_delete.remove(uri)
+                    if mtime > mtimes.get(uri, 0):
+                        handled = self.__scan_to_handle(f)
+                        if handled:
+                            # On first scan, we want file mtime
+                            mtime = int(time()) if mtimes else mtime
+                            # If not saved, use 0 as mtime, easy delete on quit
+                            if already_in_db:
+                                self.__scan_del(uri)
+                            self.__scan_add(uri, mtime if saved else 0)
+                            new_tracks.append(uri)
+                    GLib.idle_add(self.__update_progress, i, count)
+                except Exception as e:
+                    Logger.error(
+                               "CollectionScanner:: __scan_files: % s" % e)
+                i += 1
+            # This files are not in collection anymore
+            for uri in to_delete:
+                self.__scan_del(uri)
+        except Exception as e:
+            Logger.error("CollectionScanner:: __scan_files: % s" % e)
+        SqlCursor.commit(App().db)
+        SqlCursor.remove(App().db)
+        return new_tracks
+
     def __add2db(self, uri, mtime):
         """
-            Add new file to db with information
+            Add new file(or update one) to db with information
             @param uri as string
             @param mtime as int
             @return track id as int
