@@ -195,7 +195,7 @@ class Player(BinPlayer, QueuePlayer, PlaylistPlayer, RadioPlayer,
             @param filter2_ids as [int]
         """
         self._albums = []
-        album_ids = [] if album_id is None else [album_id]
+        album_ids = []
         self.reset_history()
         # We are not playing a user playlist anymore
         self._playlist_tracks = []
@@ -263,15 +263,17 @@ class Player(BinPlayer, QueuePlayer, PlaylistPlayer, RadioPlayer,
         elif shuffle_setting == Shuffle.ALBUMS:
             if album_id is None:
                 shuffle(album_ids)
-                album = Album(album_ids.pop(0), filter1_ids, filter2_ids, True)
+                album = Album(album_id, filter1_ids, filter2_ids, True)
             else:
-                album = Album(album_ids.pop(0), filter1_ids, filter2_ids, True)
+                album = Album(album_id, filter1_ids, filter2_ids, True)
                 shuffle(album_ids)
         else:
-            album = Album(album_ids.pop(0), filter1_ids, filter2_ids, True)
+            album = Album(album_id, filter1_ids, filter2_ids, True)
         # Select a track and start playback
         track = None
-        self._albums = [album]
+        if shuffle_setting == Shuffle.ALBUMS:
+            self._albums = [album]
+            album_ids.remove(album_id)
         if shuffle_setting == Shuffle.TRACKS:
             track = choice(album.tracks)
         elif shuffle_setting == Shuffle.ALBUMS:
@@ -282,8 +284,6 @@ class Player(BinPlayer, QueuePlayer, PlaylistPlayer, RadioPlayer,
 
         # Create album objects
         for _album_id in album_ids:
-            if _album_id == album_id:
-                continue
             album = Album(_album_id, filter1_ids, filter2_ids, True)
             self._albums.append(album)
         if track is not None:
@@ -330,8 +330,8 @@ class Player(BinPlayer, QueuePlayer, PlaylistPlayer, RadioPlayer,
                     radios = Radios()
                     track = Track()
                     name = radios.get_name(current_track_id)
-                    url = radios.get_url(name)
-                    track.set_radio(name, url)
+                    uri = radios.get_uri(current_track_id)
+                    track.set_radio(name, uri)
                     self.load(track, is_playing)
                 elif App().tracks.get_uri(current_track_id) != "":
                     if albums:
@@ -524,7 +524,7 @@ class Player(BinPlayer, QueuePlayer, PlaylistPlayer, RadioPlayer,
             On stream start, set next and previous track
         """
         if not App().scanner.is_locked():
-            App().window.container.pulse(False)
+            App().window.container.progress.pulse(False)
         if self._current_track.id is not None and self._current_track.id >= 0:
             ShufflePlayer._on_stream_start(self, bus, message)
         if self.track_in_queue(self._current_track):
