@@ -16,6 +16,8 @@ from math import pi
 from gettext import gettext as _
 import unicodedata
 import cairo
+import time
+from functools import wraps
 
 from lollypop.logger import Logger
 from lollypop.define import App, Type, SelectionListMask
@@ -191,6 +193,21 @@ def is_pls(f):
     return False
 
 
+def get_mtime(info):
+    """
+        Return Last modified time of a given file
+        @param info as Gio.FileInfo
+    """
+    try:
+        # We do not use time::modified because many tag editors
+        # just preserve this setting
+        return int(info.get_attribute_as_string("time::changed"))
+    except:
+        pass
+    # Fallback for remote fs
+    return int(info.get_attribute_as_string("time::modified"))
+
+
 def format_artist_name(name):
     """
         Return formated artist name
@@ -278,7 +295,7 @@ def get_icon_name(object_id, type=SelectionListMask.ARTISTS):
     elif object_id == Type.ALL:
         icon = "media-optical-cd-audio-symbolic"
     elif object_id == Type.ARTISTS:
-            icon = "avatar-default-symbolic"
+        icon = "avatar-default-symbolic"
     elif object_id == Type.COMPILATIONS:
         icon = "system-users-symbolic"
     elif object_id == Type.RECENTS:
@@ -300,3 +317,22 @@ def get_icon_name(object_id, type=SelectionListMask.ARTISTS):
     elif object_id == Type.SEARCH:
         icon = "edit-find-symbolic"
     return icon
+
+
+def profile(f):
+    """
+        Decorator to get execution time of a function
+    """
+    @wraps(f)
+    def wrapper(*args, **kwargs):
+        start_time = time.perf_counter()
+
+        ret = f(*args, **kwargs)
+
+        elapsed_time = time.perf_counter() - start_time
+        Logger.debug("%s::%s: execution time %d:%f" % (
+            f.__module__, f.__name__, elapsed_time / 60, elapsed_time % 60))
+
+        return ret
+
+    return wrapper
