@@ -10,10 +10,11 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from gi.repository import GObject, Gtk, Gdk, GLib, Gio, GdkPixbuf
+from gi.repository import Gtk, GObject, Gdk, GLib, Gio, GdkPixbuf
 
 from gettext import gettext as _
 from urllib.parse import urlparse
+from lollypop.widgets_utils import Popover
 
 from lollypop.logger import Logger
 try:
@@ -162,14 +163,18 @@ class ArtworkSearchWidget(Gtk.Bin):
         """
             Populate view
         """
-        image = Gtk.Image()
-        surface = App().art.get_default_icon("edit-clear-all-symbolic",
-                                             ArtSize.BIG,
-                                             self.get_scale_factor())
-        image.set_from_surface(surface)
+        image = Gtk.Image.new_from_icon_name("edit-clear-all-symbolic",
+                                             Gtk.IconSize.DIALOG)
         image.set_property("valign", Gtk.Align.CENTER)
         image.set_property("halign", Gtk.Align.CENTER)
-        image.get_style_context().add_class("cover-frame")
+        context = image.get_style_context()
+        context.add_class("cover-frame")
+        padding = context.get_padding(Gtk.StateFlags.NORMAL)
+        border = context.get_border(Gtk.StateFlags.NORMAL)
+        image.set_size_request(ArtSize.BIG + padding.left +
+                               padding.right + border.left + border.right,
+                               ArtSize.BIG + padding.top +
+                               padding.bottom + border.top + border.bottom)
         image.show()
         self.__view.add(image)
 
@@ -230,9 +235,7 @@ class ArtworkSearchWidget(Gtk.Bin):
                 if self.__album is not None:
                     App().art.save_album_artwork(data, self.__album.id)
                 else:
-                    InformationStore.uncache_artwork(
-                        self.__artist,
-                        button.get_scale_factor())
+                    InformationStore.uncache_artwork(self.__artist)
                     InformationStore.add_artist_artwork(self.__artist, data)
                     App().art.emit("artist-artwork-changed", self.__artist)
                 self._streams = {}
@@ -251,9 +254,7 @@ class ArtworkSearchWidget(Gtk.Bin):
             App().art.clean_album_cache(self.__album)
             App().art.emit("album-artwork-changed", self.__album.id)
         else:
-            InformationStore.uncache_artwork(
-                        self.__artist,
-                        button.get_scale_factor())
+            InformationStore.uncache_artwork(self.__artist)
             InformationStore.add_artist_artwork(self.__artist, None)
             App().art.emit("artist-artwork-changed", self.__artist)
         self.__close_popover()
@@ -356,13 +357,13 @@ class ArtworkSearchWidget(Gtk.Bin):
             return
         try:
             if loaded:
+                scale_factor = self.get_scale_factor()
                 bytes = GLib.Bytes(content)
                 stream = Gio.MemoryInputStream.new_from_bytes(bytes)
-                bytes.unref()
                 if stream is not None:
                     big = GdkPixbuf.Pixbuf.new_from_stream_at_scale(
-                        stream, ArtSize.BIG,
-                        ArtSize.BIG,
+                        stream, ArtSize.BIG * scale_factor,
+                        ArtSize.BIG * scale_factor,
                         True,
                         None)
                     stream.close()
@@ -371,9 +372,10 @@ class ArtworkSearchWidget(Gtk.Bin):
                 image.set_property("halign", Gtk.Align.CENTER)
                 image.set_property("valign", Gtk.Align.CENTER)
                 self.__contents[image] = content
-                surface = Gdk.cairo_surface_create_from_pixbuf(big,
-                                                               0,
-                                                               None)
+                surface = Gdk.cairo_surface_create_from_pixbuf(
+                                                       big,
+                                                       scale_factor,
+                                                       None)
                 image.set_from_surface(surface)
                 image.show()
                 self.__view.add(image)
@@ -387,7 +389,7 @@ class ArtworkSearchWidget(Gtk.Bin):
         """
         widget = self.get_parent()
         while widget is not None:
-            if isinstance(widget, Gtk.Popover):
+            if isinstance(widget, Popover):
                 widget.hide()
                 break
             widget = widget.get_parent()
@@ -442,9 +444,7 @@ class ArtworkSearchWidget(Gtk.Bin):
             if self.__album is not None:
                 App().art.save_album_artwork(data, self.__album.id)
             else:
-                InformationStore.uncache_artwork(
-                        self.__artist,
-                        flowbox.get_scale_factor())
+                InformationStore.uncache_artwork(self.__artist)
                 InformationStore.add_artist_artwork(self.__artist, data)
                 App().art.emit("artist-artwork-changed", self.__artist)
             self._streams = {}
